from typing import Optional

from pydantic import UUID4

from promptquality.constants.run import RunDefaults
from promptquality.types.config import PromptQualityConfig
from promptquality.types.run import GetJobStatusResponse
from promptquality.utils.logger import logger


def get_run_scorer_jobs(
    project_id: Optional[UUID4] = None, run_id: Optional[UUID4] = None
) -> list[GetJobStatusResponse]:
    config = PromptQualityConfig.get()
    project_id = project_id or config.current_project_id
    run_id = run_id or config.current_run_id
    if not project_id:
        raise ValueError("Project ID must be provided or set in config before getting run scorer jobs.")
    if not run_id:
        raise ValueError("Run ID must be provided or set in config before getting run scorer jobs.")
    logger.debug(f"Getting run scorer jobs for project {project_id}, run {run_id}...")
    response_dict = config.pq_api_client.get_run_scorer_jobs(project_id, run_id)
    jobs = [GetJobStatusResponse.model_validate(job) for job in response_dict]
    logger.debug(f"Got {len(jobs)} run scorer jobs for project {project_id}, run {run_id}.")
    return [job for job in jobs if job.job_name == RunDefaults.prompt_scorer_job_name]



from pydantic import UUID4

from galileo_core.helpers.user_integration import share_integration_with_user as core_share_integration_with_user
from galileo_core.schemas.core.integration.user_integration import UserIntegrationCollaboratorResponse
from promptquality.types.config import PromptQualityConfig


def share_integration_with_user(integration_id: UUID4, user_id: UUID4) -> UserIntegrationCollaboratorResponse:
    config = PromptQualityConfig.get()
    return core_share_integration_with_user(integration_id=integration_id, user_id=user_id, config=config)



from json import dumps
from typing import Optional, Union

from galileo_core.helpers.integration import (
    create_or_update_anthropic_integration as core_create_or_update_anthropic_integration,
)
from galileo_core.helpers.integration import (
    create_or_update_azure_integration as core_create_or_update_azure_integration,
)
from galileo_core.helpers.integration import create_or_update_integration as core_create_or_update_integration
from galileo_core.helpers.integration import (
    create_or_update_mistral_integration as core_create_or_update_mistral_integration,
)
from galileo_core.helpers.integration import (
    create_or_update_openai_integration as core_create_or_update_openai_integration,
)
from galileo_core.helpers.integration import (
    create_or_update_vertex_ai_integration as core_create_or_update_vertex_ai_integration,
)
from galileo_core.helpers.integration import list_integrations as core_list_integrations
from galileo_core.schemas.core.integration.azure import DEFAULT_AZURE_API_VERSION, AzureModelDeployment
from galileo_core.schemas.core.integration.azure_auth_type import AzureAuthenticationType
from galileo_core.schemas.core.integration.base import IntegrationResponse
from promptquality.types.config import PromptQualityConfig


def list_integrations() -> list[IntegrationResponse]:
    """
    Returns all integrations that the user has access to.

    Returns
    -------
    List[IntegrationResponse]
        A list of integrations.
    """
    config = PromptQualityConfig.get()
    return core_list_integrations(config=config)


def create_or_update_integration(name: str, data: dict) -> IntegrationResponse:
    """
    Create or update an integration.

    Parameters
    ----------
    name : str
        A name of the new integration.

    data: dict
        All additional data for the new integration.

    Returns
    -------
    IntegrationResponse
        Response object for the created or updated integration.
    """
    config = PromptQualityConfig.get()
    return core_create_or_update_integration(name=name, data=data, config=config)


def create_or_update_openai_integration(api_key: str, organization_id: Optional[str] = None) -> IntegrationResponse:
    """
    Create or update an OpenAI integration.

    Parameters
    ----------
    api_key : str
        OpenAI API key.
    organization_id : Optional[str], optional
        OpenAI organization ID, by default None.
    Returns
    -------
    IntegrationResponse
        Response object for the created or updated integration.
    """
    config = PromptQualityConfig.get()
    return core_create_or_update_openai_integration(api_key, organization_id=organization_id, config=config)


def create_or_update_azure_integration(
    api_key: Union[str, dict[str, str]],
    endpoint: str,
    proxy: bool = False,
    authentication_type: AzureAuthenticationType = AzureAuthenticationType.api_key,
    authentication_scope: Optional[str] = None,
    headers: Optional[dict[str, str]] = None,
    api_version: str = DEFAULT_AZURE_API_VERSION,
    azure_deployment: Optional[str] = None,
    available_deployments: Optional[list[AzureModelDeployment]] = None,
) -> IntegrationResponse:
    """
    Create or update an Azure integration.

    Parameters
    ----------
    api_key : str
        Azure authentication key. This can be one of:
        1. Your Azure API key. If you provide this, the authentication type should be
        `AzureAuthenticationType.api_key`.
        2. A dictionary containing the Azure Entra credentials with ID and secret. If
        you use this, `AZURE_CLIENT_ID`,
        `AZURE_CLIENT_SECRET` and `AZURE_TENANT_ID` are expected to be included and the authentication type should be `AzureAuthenticationType.client_secret`.
        3. A dictionary containing the Azure Entra credentials with username and password. If
        you use this, `AZURE_CLIENT_ID`, `AZURE_USERNAME` and `AZURE_PASSWORD` are expected to be included and the authentication type should be `AzureAuthenticationType.username_password`.
    endpoint : str
        The Azure OpenAI endpoint.
    proxy : bool, optional
        Whether to use a proxy when making requests, by default False.
    authentication_type : AzureAuthenticationType, optional
        Type of authentication to use.
    authentication_scope : Optional[str], optional
        Scope for authentication, if applicable.
    headers : Optional[dict[str, str]], optional
        Additional headers to include in requests.
    api_version : str, optional
        Azure API version to use, by default DEFAULT_AZURE_API_VERSION.
    azure_deployment : Optional[str], optional
        The default deployment name to use.
    available_deployments : Optional[List[AzureModelDeployment]], optional
        Predefined deployments to avoid querying Azure for them.

    Returns
    -------
    IntegrationResponse
        Response object for the created or updated integration.
    """
    config = PromptQualityConfig.get()
    return core_create_or_update_azure_integration(
        dumps(api_key) if isinstance(api_key, dict) else api_key,
        endpoint=endpoint,
        proxy=proxy,
        authentication_type=authentication_type,
        authentication_scope=authentication_scope,
        headers=headers,
        api_version=api_version,
        azure_deployment=azure_deployment,
        available_deployments=available_deployments,
        config=config,
    )


def create_or_update_vertex_ai_integration(token: str) -> IntegrationResponse:
    """
    Create or update a Vertex AI integration.

    Parameters
    ----------
    token : str
        Vertex AI token.
    Returns
    -------
    IntegrationResponse
        Response object for the created or updated integration.
    """
    config = PromptQualityConfig.get()
    return core_create_or_update_vertex_ai_integration(token, config=config)


def create_or_update_anthropic_integration(api_key: str) -> IntegrationResponse:
    """
    Create or update an Anthropic integration.

    Parameters
    ----------
    token : str
        Anthropic token.
    Returns
    -------
    IntegrationResponse
        Response object for the created or updated integration.
    """
    config = PromptQualityConfig.get()
    return core_create_or_update_anthropic_integration(api_key, config=config)


def create_or_update_mistral_integration(api_key: str) -> IntegrationResponse:
    """
    Create or update a Mistral integration.

    Parameters
    ----------
    token : str
        Mistral token.
    Returns
    -------
    IntegrationResponse
        Response object for the created or updated integration.
    """
    config = PromptQualityConfig.get()
    return core_create_or_update_mistral_integration(api_key, config=config)



from typing import Optional

from pydantic import UUID4

from galileo_core.helpers.user import create_user as core_create_user
from galileo_core.helpers.user import get_current_user as core_get_current_user
from galileo_core.helpers.user import invite_users as core_invite_users
from galileo_core.helpers.user import list_users as core_list_users
from galileo_core.helpers.user import update_user as core_update_user
from galileo_core.schemas.core.auth_method import AuthMethod
from galileo_core.schemas.core.user import CreateUserResponse, User
from galileo_core.schemas.core.user_role import UserRole
from promptquality.types.config import PromptQualityConfig


def get_current_user() -> User:
    config = PromptQualityConfig.get()
    return core_get_current_user(config=config)


def create_user(email: str, password: str, role: UserRole = UserRole.read_only) -> CreateUserResponse:
    """
    Create user.
    Parameters
    ----------
    email: str
        The user's email address.
    password: str
        The user's password.
    role: UserRole = UserRole.read_only
        The user's assigned role.

    Returns
    -------
    CreateUserResponse
        Created user.
    """
    config = PromptQualityConfig.get()
    return core_create_user(email=email, password=password, role=role, config=config)


def invite_users(
    emails: list[str],
    role: UserRole = UserRole.user,
    group_ids: Optional[list[UUID4]] = None,
    auth_method: AuthMethod = AuthMethod.email,
) -> None:
    """
    Invite users.

    Parameters
    ----------
    emails : List[str]
        List of emails to invite.
    role : UserRole, optional
        Roles to grant invited users, by default UserRole.user
    group_ids : Optional[List[UUID4]], optional
        Group IDs to add the users to, by default None, which means they are not added to any group.
    auth_method : AuthMethod, optional
        Authentication method to use, by default AuthMethod.email
    """
    config = PromptQualityConfig.get()
    return core_invite_users(emails=emails, role=role, group_ids=group_ids, auth_method=auth_method, config=config)


def list_users() -> list[User]:
    """
    List all users.

    Returns
    -------
    List[User]
        List of all users.
    """
    config = PromptQualityConfig.get()
    return core_list_users(config=config)


def update_user(user_id: UUID4, role: UserRole = UserRole.user) -> User:
    """
    Update user.

    Parameters
    ----------
    user_id : User.id
        User ID to update.
    role : UserRole
        New role to assign to the user.

    Returns
    -------
    User
        Updated user.
    """
    config = PromptQualityConfig.get()
    return core_update_user(user_id=user_id, role=role, config=config)



from pydantic import UUID4

from galileo_core.helpers.group_integration import share_integration_with_group as core_share_integration_with_group
from galileo_core.schemas.core.integration.group_integration import GroupIntegrationCollaboratorResponse
from promptquality.types.config import PromptQualityConfig


def share_integration_with_group(integration_id: UUID4, group_id: UUID4) -> GroupIntegrationCollaboratorResponse:
    """
    Share an integration with a group.

    Args:
        integration_id (UUID4): The ID of the integration.
        group_id (UUID4): The ID of the group.

    Returns:
        GroupIntegrationCollaboratorResponse: The response from the API.
    """
    config = PromptQualityConfig.get()
    return core_share_integration_with_group(integration_id=integration_id, group_id=group_id, config=config)
